"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTokenFromAuthHeader = void 0;
var tslib_1 = require("tslib");
var http_errors_1 = tslib_1.__importDefault(require("http-errors"));
var logger_1 = require("../logger");
function isLowerCaseAuthorizedEvent(event) {
    return typeof event.headers.authorization === "string";
}
function isUpperCaseAuthorizedEvent(event) {
    return typeof event.headers.Authorization === "string";
}
function getTokenFromAuthHeader(event) {
    logger_1.logger("Checking whether event contains at least one authorization header");
    if (!isLowerCaseAuthorizedEvent(event) &&
        !isUpperCaseAuthorizedEvent(event)) {
        return undefined;
    }
    logger_1.logger("Checking whether event contains multiple authorization headers");
    if (isLowerCaseAuthorizedEvent(event) && isUpperCaseAuthorizedEvent(event)) {
        logger_1.logger("Both authorization and Authorization headers found, only one can be set");
        throw http_errors_1.default(400, "Both authorization and Authorization headers found, only one can be set", {
            type: "MultipleAuthorizationHeadersSet",
        });
    }
    logger_1.logger("One authorization header found");
    logger_1.logger("Checking whether authorization header is formed correctly");
    var authHeader = isLowerCaseAuthorizedEvent(event)
        ? event.headers.authorization
        : event.headers.Authorization;
    var parts = authHeader.split(" ");
    if (parts.length !== 2 || parts[0] !== "Bearer") {
        logger_1.logger("Authorization header malformed, it was \"" + authHeader + "\" but should be of format \"Bearer token\"");
        throw http_errors_1.default(401, "Format should be \"Authorization: Bearer [token]\", received \"Authorization: " + authHeader + "\" instead", {
            type: "WrongAuthFormat",
        });
    }
    logger_1.logger("Authorization header formed correctly");
    return parts[1];
}
exports.getTokenFromAuthHeader = getTokenFromAuthHeader;
//# sourceMappingURL=getTokenFromAuthHeader.js.map